@@ -10,9 +10,9 @@ class TA_Pre:
     '''
     def __init__(self, Data):
         '''
-        Upon initialization the ``check_w_orientation`` function is called, to ensure that the wavelengths are in numberical order. The raw data is then separated into TA data ``D`` and its corresponding wavelengths ``w`` and timedelays ``t``.
+        Upon initialization the ``check_w_orientation`` function is called, to ensure that the wavelengths are in numberical order. The raw data is then separated into TA data ``D`` and its corresponding wavelengths ``w`` and timedelays ``t`` .
         
-        :param Data: A numpy object in the form of the raw TA data without any preprocessing. i.e. ``TA_Pre(np.loadtxt('sample_800nm_5nJ.txt'))``
+        :param Data: A numpy object in the form of the raw TA data without any preprocessing. i.e. ``TA_Pre(np.loadtxt('sample_800nm_5nJ.txt'))`` .
         
         :attributes TA Data: 
                     * self.Data - Raw data is it was uploaded after orientation change.
@@ -80,7 +80,7 @@ class TA_Pre:
     #Chirp correction function
     def chirp_correction(self):
         '''
-        Since the white light pulse is chirped, meaning that the blue side of the white light distribution arrives at the sample before the red side, the time zeros of the rise of the signal is different for each wavelength. This wavelength dependant time zero can be approximated by an exponential function (here ``func``). This exponential is then used to create a new set of timedelays for each wavelength is a way that the rise of the signal is at time zero. The time-shifted signals are then interpolated back onto the origional timedelays and the data matrix ``D``is redefined.
+        Since the white light pulse is chirped, meaning that the blue side of the white light distribution arrives at the sample before the red side, the time zeros of the rise of the signal is different for each wavelength. This wavelength dependant time zero can be approximated by an exponential function. This exponential is then used to create a new set of timedelays for each wavelength is a way that the rise of the signal is at time zero. The time-shifted signals are then interpolated back onto the origional timedelays and the data matrix is redefined.
         '''
         def func(x,y0,A,tau,x0):
             return y0 + A*np.exp(-(x-x0)/tau)
@@ -145,7 +145,7 @@ class TA_Pre:
         size = '75%'
         wRange = widgets.IntRangeSlider(description = 'Wavelength Range',
                                         value = [self.w.min(),self.w.max()],
-                                        min=self.w.min(), max=self.w.max(), step=10,
+                                        min=self.w.min(), max=self.w.max(), step=5,
                                         style = {'description_width': 'initial'},
                                         layout=widgets.Layout(width=size))
         tRange = widgets.IntRangeSlider(description = 'Timedelay Range',
@@ -155,7 +155,7 @@ class TA_Pre:
                                         layout=widgets.Layout(width=size))
         ARange = widgets.FloatRangeSlider(description = 'Amplitude Range',
                                         value = [-0.85,1.01],
-                                        min=-3, max=3, step=0.1,
+                                        min=-5, max=5, step=0.1,
                                         style = {'description_width': 'initial'},
                                         layout=widgets.Layout(width=size))
         neg_sub = widgets.FloatSlider(description = 'Subtract Negative from',
@@ -172,7 +172,7 @@ class TA_Pre:
                                         layout=widgets.Layout(width=size))
         A = widgets.FloatSlider(description = r'\(A\)',
                                         value = -0.423,
-                                        min=-10, max=10, step=0.05,
+                                        min=-10, max=10, step=0.01,
                                         layout=widgets.Layout(width=size))
         tau = widgets.FloatSlider(description = r'\(\tau\)',
                                         value = 289.9,
@@ -291,7 +291,7 @@ class TA:
             plt.xscale('log')
         if norm:
             plt.ylim(0,1.1)
-        plt.xlim(min(self.time),max(self.time))
+        plt.xlim(self.time[np.where(self.time > 0)[0][0]],max(self.time))
         plt.legend()
         plt.xlabel('Timedelays (ps)')
         plt.ylabel('\u0394A ')
